/******************************************************************************

  Parameter.C
  
  Stephen Freund
  freunds@cs.stanford.edu

  Computes the parameters using the given formula, and stored the results
  so that they will not have to be repeated again.

******************************************************************************/

#include "Parameter.h"
#include "math.h"
#include "CGraph.h"
#include <stdio.h>
#include <stdlib.h>
#include <float.h>
#include "Utility.h"

/*
 * The values.  I just have them set to some base value for the start 
 * of things.
 */
static double sigma = .05;
static double alpha = 200;
static double epsilon = 0.05;
static double log_2 = log(2);

/*
 * These are implemented as macros so that they can be printed
 * to the output.  See PrintParameterFunctions below.
 */
#define ALPHA    (1 / largestExcess  * log(k * m) / log_2)

#define SIGMA    (2 * largestExcess / Max(2*n, m) )

#define EPSILON  (0.05)

/*
 * Compute the parameters.  Pass in the graph in order to get information
 * about the number of nodes, etc.
 */
void ComputeParameters(CGraph *theGraph)  {
  double n = theGraph -> GetNumNodes();
  double m = theGraph -> GetNumEdges();
  double k = theGraph -> GetNumCommodities();
  double largestExcess = theGraph -> GetLargestExcess();
  
  epsilon = EPSILON;
  alpha = ALPHA;
  sigma = SIGMA;
}

double GetEpsilon(void)  {
  return (epsilon);
}

double GetSigma(void)  {
  return (sigma);
}

double GetAlpha(void)  {
  return (alpha);
}

/*
 * Ugly macro trick that will allow me to use the parameter to STRING
 * as a string constant.  See below.
 */
#define MS(X)			#X
#define STRING(X)		MS(X)

void PrintParameterFunctions(void)  {
  cout << "   epsilon = " << STRING(EPSILON) "\n";
  cout << "   alpha   = " << STRING(ALPHA) "\n";
  cout << "   sigma   = " << STRING(SIGMA) "\n\n";
}




